@@ -127,9 +127,26 @@ class ShadeAdapter(adapter.Adapter):
         except Exception:
             return self._log_request_id(response)
 
+        # Note(rods): this is just a temporary step needed until we
+        # don't update all the other REST API calls
+        if isinstance(result_json, dict):
+            for key in ['volumes', 'volume', 'volumeAttachment', 'backups',
+                        'volume_types', 'volume_type_access', 'snapshots',
+                        'network', 'networks', 'subnet', 'subnets',
+                        'router', 'routers', 'floatingip', 'floatingips',
+                        'floating_ip', 'floating_ips', 'port', 'ports',
+                        'stack', 'stacks', 'zones', 'events',
+                        'security_group', 'security_groups',
+                        'security_group_rule', 'security_group_rules',
+                        'users', 'user', 'projects', 'tenants',
+                        'project', 'tenant']:
+                if key in result_json.keys():
+                    self._log_request_id(response)
+                    return result_json
+
         if isinstance(result_json, list):
             self._log_request_id(response)
-            return meta.obj_list_to_dict(result_json)
+            return meta.obj_list_to_munch(result_json)
 
         result = None
         if isinstance(result_json, dict):
@@ -149,9 +166,9 @@ class ShadeAdapter(adapter.Adapter):
         self._log_request_id(response, result)
 
         if isinstance(result, list):
-            return meta.obj_list_to_dict(result)
+            return meta.obj_list_to_munch(result)
         elif isinstance(result, dict):
-            return meta.obj_to_dict(result)
+            return meta.obj_to_munch(result)
         return result
 
     def request(
