@@ -25,7 +25,6 @@ import sys
 import time
 
 from decorator import decorator
-from novaclient import exceptions as nova_exc
 
 from shade import _log
 from shade import exc
@@ -48,7 +47,7 @@ def _iterate_timeout(timeout, message, wait=2):
     with <message>.
 
     """
-    log = _log.setup_logging(__name__)
+    log = _log.setup_logging('shade.iterate_timeout')
 
     try:
         # None as a wait winds up flowing well in the per-resource cache
@@ -249,7 +248,7 @@ def normalize_keystone_services(services):
             'enabled': service['enabled']
         }
         ret.append(new_service)
-    return meta.obj_list_to_dict(ret)
+    return meta.obj_list_to_munch(ret)
 
 
 def localhost_supports_ipv6():
@@ -277,7 +276,7 @@ def normalize_users(users):
             description=user.get('description')
         ) for user in users
     ]
-    return meta.obj_list_to_dict(ret)
+    return meta.obj_list_to_munch(ret)
 
 
 def normalize_domains(domains):
@@ -289,7 +288,7 @@ def normalize_domains(domains):
             enabled=domain.get('enabled'),
         ) for domain in domains
     ]
-    return meta.obj_list_to_dict(ret)
+    return meta.obj_list_to_munch(ret)
 
 
 def normalize_groups(domains):
@@ -302,7 +301,7 @@ def normalize_groups(domains):
             domain_id=domain.get('domain_id'),
         ) for domain in domains
     ]
-    return meta.obj_list_to_dict(ret)
+    return meta.obj_list_to_munch(ret)
 
 
 def normalize_role_assignments(assignments):
@@ -363,7 +362,7 @@ def normalize_roles(roles):
             name=role.get('name'),
         ) for role in roles
     ]
-    return meta.obj_list_to_dict(ret)
+    return meta.obj_list_to_munch(ret)
 
 
 def normalize_flavor_accesses(flavor_accesses):
@@ -445,10 +444,6 @@ def shade_exceptions(error_message=None):
         yield
     except exc.OpenStackCloudException:
         raise
-    except nova_exc.BadRequest as e:
-        if error_message is None:
-            error_message = str(e)
-        raise exc.OpenStackCloudBadRequest(error_message)
     except Exception as e:
         if error_message is None:
             error_message = str(e)
