@@ -15,9 +15,9 @@ import iso8601
 import jsonpatch
 
 from ironicclient import exceptions as ironic_exceptions
-from novaclient import exceptions as nova_exceptions
 
 from shade.exc import *  # noqa
+from shade import meta
 from shade import openstackcloud
 from shade import _tasks
 from shade import _utils
@@ -1687,6 +1687,11 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         :param bool wait: Wait for role to be granted
         :param int timeout: Timeout to wait for role to be granted
 
+        NOTE: domain is a required argument when the grant is on a project,
+            user or group specified by name. In that situation, they are all
+            considered to be in that domain. If different domains are in use
+            in the same role grant, it is required to specify those by ID.
+
         NOTE: for wait and timeout, sometimes granting roles is not
               instantaneous for granting roles.
 
@@ -1806,8 +1811,9 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         :returns: A list of hypervisor ``munch.Munch``.
         """
 
-        with _utils.shade_exceptions("Error fetching hypervisor list"):
-            return self.manager.submit_task(_tasks.HypervisorList())
+        return self._compute_client.get(
+            '/os-hypervisors/detail',
+            error_message="Error fetching hypervisor list")
 
     def search_aggregates(self, name_or_id=None, filters=None):
         """Seach host aggregates.
@@ -1829,8 +1835,9 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         :returns: A list of aggregate dicts.
 
         """
-        with _utils.shade_exceptions("Error fetching aggregate list"):
-            return self.manager.submit_task(_tasks.AggregateList())
+        return self._compute_client.get(
+            '/os-aggregates',
+            error_message="Error fetching aggregate list")
 
     def get_aggregate(self, name_or_id, filters=None):
         """Get an aggregate by name or ID.
@@ -1863,11 +1870,14 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
 
         :raises: OpenStackCloudException on operation error.
         """
-        with _utils.shade_exceptions(
-                "Unable to create host aggregate {name}".format(
-                    name=name)):
-            return self.manager.submit_task(_tasks.AggregateCreate(
-                name=name, availability_zone=availability_zone))
+        return self._compute_client.post(
+            '/os-aggregates',
+            json={'aggregate': {
+                'name': name,
+                'availability_zone': availability_zone
+            }},
+            error_message="Unable to create host aggregate {name}".format(
+                name=name))
 
     @_utils.valid_kwargs('name', 'availability_zone')
     def update_aggregate(self, name_or_id, **kwargs):
@@ -1886,13 +1896,11 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException(
                 "Host aggregate %s not found." % name_or_id)
 
-        with _utils.shade_exceptions(
-                "Error updating aggregate {name}".format(name=name_or_id)):
-            new_aggregate = self.manager.submit_task(
-                _tasks.AggregateUpdate(
-                    aggregate=aggregate['id'], values=kwargs))
-
-        return new_aggregate
+        return self._compute_client.put(
+            '/os-aggregates/{id}'.format(id=aggregate['id']),
+            json={'aggregate': kwargs},
+            error_message="Error updating aggregate {name}".format(
+                name=name_or_id))
 
     def delete_aggregate(self, name_or_id):
         """Delete a host aggregate.
@@ -1908,10 +1916,10 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             self.log.debug("Aggregate %s not found for deleting", name_or_id)
             return False
 
-        with _utils.shade_exceptions(
-                "Error deleting aggregate {name}".format(name=name_or_id)):
-            self.manager.submit_task(
-                _tasks.AggregateDelete(aggregate=aggregate['id']))
+        return self._compute_client.delete(
+            '/os-aggregates/{id}'.format(id=aggregate['id']),
+            error_message="Error deleting aggregate {name}".format(
+                name=name_or_id))
 
         return True
 
@@ -1931,11 +1939,13 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException(
                 "Host aggregate %s not found." % name_or_id)
 
-        with _utils.shade_exceptions(
-                "Unable to set metadata for host aggregate {name}".format(
-                    name=name_or_id)):
-            return self.manager.submit_task(_tasks.AggregateSetMetadata(
-                aggregate=aggregate['id'], metadata=metadata))
+        err_msg = "Unable to set metadata for host aggregate {name}".format(
+            name=name_or_id)
+
+        return self._compute_client.post(
+            '/os-aggregates/{id}/action'.format(id=aggregate['id']),
+            json={'set_metadata': {'metadata': metadata}},
+            error_message=err_msg)
 
     def add_host_to_aggregate(self, name_or_id, host_name):
         """Add a host to an aggregate.
@@ -1950,11 +1960,13 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException(
                 "Host aggregate %s not found." % name_or_id)
 
-        with _utils.shade_exceptions(
-                "Unable to add host {host} to aggregate {name}".format(
-                    name=name_or_id, host=host_name)):
-            return self.manager.submit_task(_tasks.AggregateAddHost(
-                aggregate=aggregate['id'], host=host_name))
+        err_msg = "Unable to add host {host} to aggregate {name}".format(
+            host=host_name, name=name_or_id)
+
+        return self._compute_client.post(
+            '/os-aggregates/{id}/action'.format(id=aggregate['id']),
+            json={'add_host': {'host': host_name}},
+            error_message=err_msg)
 
     def remove_host_from_aggregate(self, name_or_id, host_name):
         """Remove a host from an aggregate.
@@ -1969,11 +1981,13 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException(
                 "Host aggregate %s not found." % name_or_id)
 
-        with _utils.shade_exceptions(
-                "Unable to remove host {host} from aggregate {name}".format(
-                    name=name_or_id, host=host_name)):
-            return self.manager.submit_task(_tasks.AggregateRemoveHost(
-                aggregate=aggregate['id'], host=host_name))
+        err_msg = "Unable to remove host {host} to aggregate {name}".format(
+            host=host_name, name=name_or_id)
+
+        return self._compute_client.post(
+            '/os-aggregates/{id}/action'.format(id=aggregate['id']),
+            json={'remove_host': {'host': host_name}},
+            error_message=err_msg)
 
     def get_volume_type_access(self, name_or_id):
         """Return a list of volume_type_access.
@@ -1987,13 +2001,12 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException(
                 "VolumeType not found: %s" % name_or_id)
 
-        with _utils.shade_exceptions(
-                "Unable to get volume type access {name}".format(
-                    name=name_or_id)):
-            return self._normalize_volume_type_accesses(
-                self._volume_client.get(
-                    '/types/{id}/os-volume-type-access'.format(
-                        id=volume_type.id)))
+        data = self._volume_client.get(
+            '/types/{id}/os-volume-type-access'.format(id=volume_type.id),
+            error_message="Unable to get volume type access"
+                          " {name}".format(name=name_or_id))
+        return self._normalize_volume_type_accesses(
+            meta.get_and_munchify('volume_type_access', data))
 
     def add_volume_type_access(self, name_or_id, project_id):
         """Grant access on a volume_type to a project.
@@ -2061,13 +2074,11 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         # volume_quotas = {key: val for key, val in kwargs.items()
         #                 if key in quota.VOLUME_QUOTAS}
 
-        try:
-            self.manager.submit_task(
-                _tasks.NovaQuotasSet(tenant_id=proj.id,
-                                     force=True,
-                                     **kwargs))
-        except nova_exceptions.BadRequest:
-            raise OpenStackCloudException("No valid quota or resource")
+        kwargs['force'] = True
+        self._compute_client.put(
+            '/os-quota-sets/{project}'.format(project=proj.id),
+            json={'quota_set': kwargs},
+            error_message="No valid quota or resource")
 
     def get_compute_quotas(self, name_or_id):
         """ Get quota for a project
@@ -2080,11 +2091,8 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         proj = self.get_project(name_or_id)
         if not proj:
             raise OpenStackCloudException("project does not exist")
-        try:
-            return self.manager.submit_task(
-                _tasks.NovaQuotasGet(tenant_id=proj.id))
-        except nova_exceptions.BadRequest:
-            raise OpenStackCloudException("nova client call failed")
+        return self._compute_client.get(
+            '/os-quota-sets/{project}'.format(project=proj.id))
 
     def delete_compute_quotas(self, name_or_id):
         """ Delete quota for a project
@@ -2098,11 +2106,8 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
         proj = self.get_project(name_or_id)
         if not proj:
             raise OpenStackCloudException("project does not exist")
-        try:
-            return self.manager.submit_task(
-                _tasks.NovaQuotasDelete(tenant_id=proj.id))
-        except nova_exceptions.BadRequest:
-            raise OpenStackCloudException("nova client call failed")
+        return self._compute_client.delete(
+            '/os-quota-sets/{project}'.format(project=proj.id))
 
     def get_compute_usage(self, name_or_id, start=None, end=None):
         """ Get usage for a specific project
@@ -2159,11 +2164,11 @@ class OperatorCloud(openstackcloud.OpenStackCloud):
             raise OpenStackCloudException("project does not exist: {}".format(
                 name=proj.id))
 
-        with _utils.shade_exceptions(
-                "Unable to get resources usage for project: {name}".format(
-                    name=proj.id)):
-            usage = self.manager.submit_task(
-                _tasks.NovaUsageGet(tenant_id=proj.id, start=start, end=end))
+        usage = self._compute_client.get(
+            '/os-simple-tenant-usage/{project}'.format(project=proj.id),
+            params=dict(start=start.isoformat(), end=end.isoformat()),
+            error_message="Unable to get usage for project: {name}".format(
+                name=proj.id))
 
         return self._normalize_compute_usage(usage)
 
