@@ -17,6 +17,8 @@ fakes
 Fakes used for testing
 """
 
+import datetime
+import json
 import uuid
 
 from shade._heat import template_format
@@ -31,6 +33,7 @@ ORCHESTRATION_ENDPOINT = 'https://orchestration.example.com/v1/{p}'.format(
     p=PROJECT_ID)
 NO_MD5 = '93b885adfe0da089cdf634904fd59f71'
 NO_SHA256 = '6e340b9cffb37a989ca544e6bb780a2c78901d3fb33738768511a30617afa01d'
+FAKE_PUBLIC_KEY = "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQCkF3MX59OrlBs3dH5CU7lNmvpbrgZxSpyGjlnE8Flkirnc/Up22lpjznoxqeoTAwTW034k7Dz6aYIrZGmQwe2TkE084yqvlj45Dkyoj95fW/sZacm0cZNuL69EObEGHdprfGJQajrpz22NQoCD8TFB8Wv+8om9NH9Le6s+WPe98WC77KLw8qgfQsbIey+JawPWl4O67ZdL5xrypuRjfIPWjgy/VH85IXg/Z/GONZ2nxHgSShMkwqSFECAC5L3PHB+0+/12M/iikdatFSVGjpuHvkLOs3oe7m6HlOfluSJ85BzLWBbvva93qkGmLg4ZAc8rPh2O+YIsBUHNLLMM/oQp Generated-by-Nova\n"  # flake8: noqa
 
 
 def make_fake_flavor(flavor_id, name, ram=100, disk=1600, vcpus=24):
@@ -81,33 +84,45 @@ outputs:
 FAKE_TEMPLATE_CONTENT = template_format.parse(FAKE_TEMPLATE)
 
 
-def make_fake_server(server_id, name, status='ACTIVE'):
-    return {
+def make_fake_server(
+        server_id, name, status='ACTIVE', admin_pass=None,
+        addresses=None, image=None, flavor=None):
+    if addresses is None:
+        if status == 'ACTIVE':
+            addresses = {
+                "private": [
+                    {
+                        "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
+                        "version": 6,
+                        "addr": "fddb:b018:307:0:f816:3eff:fedf:b08d",
+                        "OS-EXT-IPS:type": "fixed"},
+                    {
+                        "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
+                        "version": 4,
+                        "addr": "10.1.0.9",
+                        "OS-EXT-IPS:type": "fixed"},
+                    {
+                        "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
+                        "version": 4,
+                        "addr": "172.24.5.5",
+                        "OS-EXT-IPS:type": "floating"}]}
+        else:
+            addresses = {}
+    if image is None:
+        image = {"id": "217f3ab1-03e0-4450-bf27-63d52b421e9e",
+                 "links": []}
+    if flavor is None:
+        flavor = {"id": "64",
+                  "links": []}
+
+    server = {
         "OS-EXT-STS:task_state": None,
-        "addresses": {
-            "private": [
-                {
-                    "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
-                    "version": 6,
-                    "addr": "fddb:b018:307:0:f816:3eff:fedf:b08d",
-                    "OS-EXT-IPS:type": "fixed"},
-                {
-                    "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
-                    "version": 4,
-                    "addr": "10.1.0.9",
-                    "OS-EXT-IPS:type": "fixed"},
-                {
-                    "OS-EXT-IPS-MAC:mac_addr": "fa:16:3e:df:b0:8d",
-                    "version": 4,
-                    "addr": "172.24.5.5",
-                    "OS-EXT-IPS:type": "floating"}]},
+        "addresses": addresses,
         "links": [],
-        "image": {"id": "217f3ab1-03e0-4450-bf27-63d52b421e9e",
-                  "links": []},
+        "image": image,
         "OS-EXT-STS:vm_state": "active",
         "OS-SRV-USG:launched_at": "2017-03-23T23:57:38.000000",
-        "flavor": {"id": "64",
-                   "links": []},
+        "flavor": flavor,
         "id": server_id,
         "security_groups": [{"name": "default"}],
         "user_id": "9c119f4beaaa438792ce89387362b3ad",
@@ -125,9 +140,24 @@ def make_fake_server(server_id, name, status='ACTIVE'):
         "key_name": None,
         "name": name,
         "created": "2017-03-23T23:57:12Z",
-        "tenant_id": "fdbf563e9d474696b35667254e65b45b",
+        "tenant_id": PROJECT_ID,
         "os-extended-volumes:volumes_attached": [],
         "config_drive": "True"}
+    if admin_pass:
+        server['adminPass'] = admin_pass
+    return json.loads(json.dumps(server))
+
+
+def make_fake_keypair(name):
+    # Note: this is literally taken from:
+    # https://developer.openstack.org/api-ref/compute/
+    return {
+        "fingerprint": "7e:eb:ab:24:ba:d1:e1:88:ae:9a:fb:66:53:df:d3:bd",
+        "name": name,
+        "type": "ssh",
+        "public_key": FAKE_PUBLIC_KEY,
+        "created_at": datetime.datetime.now().isoformat(),
+    }
 
 
 def make_fake_stack(id, name, description=None, status='CREATE_COMPLETE'):
@@ -214,7 +244,7 @@ def make_fake_image(
 def make_fake_machine(machine_name, machine_id=None):
     if not machine_id:
         machine_id = uuid.uuid4().hex
-    return meta.obj_to_dict(FakeMachine(
+    return meta.obj_to_munch(FakeMachine(
         id=machine_id,
         name=machine_name))
 
@@ -228,43 +258,58 @@ class FakeFloatingIP(object):
         self.instance_id = instance_id
 
 
-class FakeServer(object):
-    def __init__(
-            self, id, name, status, addresses=None,
-            accessIPv4='', accessIPv6='', private_v4='',
-            private_v6='', public_v4='', public_v6='',
-            interface_ip='',
-            flavor=None, image=None, adminPass=None,
-            metadata=None):
-        self.id = id
-        self.name = name
-        self.status = status
-        if not addresses:
-            self.addresses = {}
-        else:
-            self.addresses = addresses
-        if not flavor:
-            flavor = {}
-        self.flavor = flavor
-        if not image:
-            image = {}
-        self.image = image
-        self.accessIPv4 = accessIPv4
-        self.accessIPv6 = accessIPv6
-        self.private_v4 = private_v4
-        self.public_v4 = public_v4
-        self.private_v6 = private_v6
-        self.public_v6 = public_v6
-        self.adminPass = adminPass
-        self.metadata = metadata
-        self.interface_ip = interface_ip
+def make_fake_server_group(id, name, policies):
+    return json.loads(json.dumps({
+        'id': id,
+        'name': name,
+        'policies': policies,
+        'members': [],
+        'metadata': {},
+    }))
 
 
-class FakeServerGroup(object):
-    def __init__(self, id, name, policies):
-        self.id = id
-        self.name = name
-        self.policies = policies
+def make_fake_hypervisor(id, name):
+    return json.loads(json.dumps({
+        'id': id,
+        'hypervisor_hostname': name,
+        'state': 'up',
+        'status': 'enabled',
+        "cpu_info": {
+            "arch": "x86_64",
+            "model": "Nehalem",
+            "vendor": "Intel",
+            "features": [
+                "pge",
+                "clflush"
+            ],
+            "topology": {
+                "cores": 1,
+                "threads": 1,
+                "sockets": 4
+            }
+        },
+        "current_workload": 0,
+        "status": "enabled",
+        "state": "up",
+        "disk_available_least": 0,
+        "host_ip": "1.1.1.1",
+        "free_disk_gb": 1028,
+        "free_ram_mb": 7680,
+        "hypervisor_type": "fake",
+        "hypervisor_version": 1000,
+        "local_gb": 1028,
+        "local_gb_used": 0,
+        "memory_mb": 8192,
+        "memory_mb_used": 512,
+        "running_vms": 0,
+        "service": {
+            "host": "host1",
+            "id": 7,
+            "disabled_reason": None
+        },
+        "vcpus": 1,
+        "vcpus_used": 0
+    }))
 
 
 class FakeVolume(object):
@@ -319,13 +364,45 @@ class FakeMachinePort(object):
         self.node_id = node_id
 
 
-class FakeSecgroup(object):
-    def __init__(self, id, name, description='', project_id=None, rules=None):
-        self.id = id
-        self.name = name
-        self.description = description
-        self.project_id = project_id
-        self.rules = rules
+def make_fake_neutron_security_group(
+        id, name, description, rules, project_id=None):
+    if not rules:
+        rules = []
+    if not project_id:
+        project_id = PROJECT_ID
+    return json.loads(json.dumps({
+        'id': id,
+        'name': name,
+        'description': description,
+        'project_id': project_id,
+        'tenant_id': project_id,
+        'security_group_rules': rules,
+    }))
+
+
+def make_fake_nova_security_group_rule(
+        id, from_port, to_port, ip_protocol, cidr):
+    return json.loads(json.dumps({
+        'id': id,
+        'from_port': int(from_port),
+        'to_port': int(to_port),
+        'ip_protcol': 'tcp',
+        'ip_range': {
+            'cidr': cidr
+        }
+    }))
+
+
+def make_fake_nova_security_group(id, name, description, rules):
+    if not rules:
+        rules = []
+    return json.loads(json.dumps({
+        'id': id,
+        'name': name,
+        'description': description,
+        'tenant_id': PROJECT_ID,
+        'rules': rules,
+    }))
 
 
 class FakeNovaSecgroupRule(object):
@@ -340,13 +417,6 @@ class FakeNovaSecgroupRule(object):
         self.parent_group_id = parent_group_id
 
 
-class FakeKeypair(object):
-    def __init__(self, id, name, public_key):
-        self.id = id
-        self.name = name
-        self.public_key = public_key
-
-
 class FakeHypervisor(object):
     def __init__(self, id, hostname):
         self.id = id
@@ -377,15 +447,22 @@ class FakeRecordset(object):
         self.records = records
 
 
-class FakeAggregate(object):
-    def __init__(self, id, name, availability_zone=None, metadata=None,
-                 hosts=None):
-        self.id = id
-        self.name = name
-        self.availability_zone = availability_zone
-        if not metadata:
-            metadata = {}
-        self.metadata = metadata
-        if not hosts:
-            hosts = []
-        self.hosts = hosts
+def make_fake_aggregate(id, name, availability_zone='nova',
+                        metadata=None, hosts=None):
+    if not metadata:
+        metadata = {}
+    if not hosts:
+        hosts = []
+    return json.loads(json.dumps({
+        "availability_zone": availability_zone,
+        "created_at": datetime.datetime.now().isoformat(),
+        "deleted": False,
+        "deleted_at": None,
+        "hosts": hosts,
+        "id": int(id),
+        "metadata": {
+            "availability_zone": availability_zone,
+        },
+        "name": name,
+        "updated_at": None,
+    }))
