@@ -27,8 +27,13 @@ from shade import _utils
 
 class TestCompute(base.BaseFunctionalTestCase):
     def setUp(self):
+        # OS_TEST_TIMEOUT is 60 sec by default
+        # but on a bad day, test_attach_detach_volume can take more time.
+        self.TIMEOUT_SCALING_FACTOR = 1.5
+
         super(TestCompute, self).setUp()
-        self.flavor = pick_flavor(self.user_cloud.list_flavors())
+        self.flavor = pick_flavor(
+            self.user_cloud.list_flavors(get_extra=False))
         if self.flavor is None:
             self.assertFalse('no sensible flavor available')
         self.image = self.pick_image()
@@ -66,6 +71,19 @@ class TestCompute(base.BaseFunctionalTestCase):
             self.user_cloud.delete_server(self.server_name, wait=True))
         self.assertIsNone(self.user_cloud.get_server(self.server_name))
 
+    def test_attach_detach_volume(self):
+        server_name = self.getUniqueString()
+        self.addCleanup(self._cleanup_servers_and_volumes, server_name)
+        server = self.user_cloud.create_server(
+            name=server_name, image=self.image, flavor=self.flavor,
+            wait=True)
+        volume = self.user_cloud.create_volume(1)
+        vol_attachment = self.user_cloud.attach_volume(server, volume)
+        for key in ('device', 'serverId', 'volumeId'):
+            self.assertIn(key, vol_attachment)
+            self.assertTrue(vol_attachment[key])  # assert string is not empty
+        self.assertIsNone(self.user_cloud.detach_volume(server, volume))
+
     def test_list_all_servers(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         server = self.user_cloud.create_server(
@@ -131,6 +149,10 @@ class TestCompute(base.BaseFunctionalTestCase):
             if len(log) > 0:
                 break
 
+    def test_list_availability_zone_names(self):
+        self.assertEqual(
+            ['nova'], self.user_cloud.list_availability_zone_names())
+
     def test_get_server_console_bad_server(self):
         self.assertRaises(
             exc.OpenStackCloudException,
@@ -360,7 +382,7 @@ class TestCompute(base.BaseFunctionalTestCase):
         self.assertEqual(set(updated_server.metadata.items()), set([]))
 
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exc.OpenStackCloudURINotFound,
             self.user_cloud.delete_server_metadata,
             self.server_name, ['key1'])
 
