@@ -98,7 +98,7 @@ class TestMemoryCache(base.RequestsMockTestCase):
             cloud_config_fixture='clouds_cache.yaml')
 
     def _image_dict(self, fake_image):
-        return self.cloud._normalize_image(meta.obj_to_dict(fake_image))
+        return self.cloud._normalize_image(meta.obj_to_munch(fake_image))
 
     def _munch_images(self, fake_image):
         return self.cloud._normalize_images([fake_image])
@@ -107,7 +107,6 @@ class TestMemoryCache(base.RequestsMockTestCase):
         self.assertIsInstance(self.cloud, shade.OpenStackCloud)
 
     def test_list_projects_v3(self):
-        self._add_discovery_uri_call()
         project_one = self._get_project_data()
         project_two = self._get_project_data()
         project_list = [project_one, project_two]
@@ -128,18 +127,18 @@ class TestMemoryCache(base.RequestsMockTestCase):
 
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(first_response['projects'])),
+                meta.obj_list_to_munch(first_response['projects'])),
             self.cloud.list_projects())
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(first_response['projects'])),
+                meta.obj_list_to_munch(first_response['projects'])),
             self.cloud.list_projects())
         # invalidate the list_projects cache
         self.cloud.list_projects.invalidate(self.cloud)
         # ensure the new values are now retrieved
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(second_response['projects'])),
+                meta.obj_list_to_munch(second_response['projects'])),
             self.cloud.list_projects())
         self.assert_calls()
 
@@ -164,41 +163,46 @@ class TestMemoryCache(base.RequestsMockTestCase):
 
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(first_response['tenants'])),
+                meta.obj_list_to_munch(first_response['tenants'])),
             self.cloud.list_projects())
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(first_response['tenants'])),
+                meta.obj_list_to_munch(first_response['tenants'])),
             self.cloud.list_projects())
         # invalidate the list_projects cache
         self.cloud.list_projects.invalidate(self.cloud)
         # ensure the new values are now retrieved
         self.assertEqual(
             self.cloud._normalize_projects(
-                meta.obj_list_to_dict(second_response['tenants'])),
+                meta.obj_list_to_munch(second_response['tenants'])),
             self.cloud.list_projects())
         self.assert_calls()
 
-    @mock.patch('shade.OpenStackCloud.nova_client')
-    def test_list_servers_no_herd(self, nova_mock):
+    def test_list_servers_no_herd(self):
         self.cloud._SERVER_AGE = 2
-        fake_server = fakes.FakeServer('1234', '', 'ACTIVE')
-        nova_mock.servers.list.return_value = [fake_server]
+        fake_server = fakes.make_fake_server('1234', 'name')
+        self.register_uris([
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers', 'detail']),
+                 json={'servers': [fake_server]}),
+        ])
         with concurrent.futures.ThreadPoolExecutor(16) as pool:
             for i in range(16):
                 pool.submit(lambda: self.cloud.list_servers(bare=True))
                 # It's possible to race-condition 16 threads all in the
                 # single initial lock without a tiny sleep
                 time.sleep(0.001)
-        self.assertEqual(1, nova_mock.servers.list.call_count)
+
+        self.assert_calls()
 
     def test_list_volumes(self):
         fake_volume = fakes.FakeVolume('volume1', 'available',
                                        'Volume 1 Display Name')
-        fake_volume_dict = meta.obj_to_dict(fake_volume)
+        fake_volume_dict = meta.obj_to_munch(fake_volume)
         fake_volume2 = fakes.FakeVolume('volume2', 'available',
                                         'Volume 2 Display Name')
-        fake_volume2_dict = meta.obj_to_dict(fake_volume2)
+        fake_volume2_dict = meta.obj_to_munch(fake_volume2)
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
@@ -225,10 +229,10 @@ class TestMemoryCache(base.RequestsMockTestCase):
     def test_list_volumes_creating_invalidates(self):
         fake_volume = fakes.FakeVolume('volume1', 'creating',
                                        'Volume 1 Display Name')
-        fake_volume_dict = meta.obj_to_dict(fake_volume)
+        fake_volume_dict = meta.obj_to_munch(fake_volume)
         fake_volume2 = fakes.FakeVolume('volume2', 'available',
                                         'Volume 2 Display Name')
-        fake_volume2_dict = meta.obj_to_dict(fake_volume2)
+        fake_volume2_dict = meta.obj_to_munch(fake_volume2)
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
@@ -248,12 +252,12 @@ class TestMemoryCache(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_create_volume_invalidates(self):
-        fake_volb4 = meta.obj_to_dict(
+        fake_volb4 = meta.obj_to_munch(
             fakes.FakeVolume('volume1', 'available', ''))
         _id = '12345'
-        fake_vol_creating = meta.obj_to_dict(
+        fake_vol_creating = meta.obj_to_munch(
             fakes.FakeVolume(_id, 'creating', ''))
-        fake_vol_avail = meta.obj_to_dict(
+        fake_vol_avail = meta.obj_to_munch(
             fakes.FakeVolume(_id, 'available', ''))
 
         def now_deleting(request, context):
@@ -312,7 +316,6 @@ class TestMemoryCache(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_list_users(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data(email='test@example.com')
         self.register_uris([
             dict(method='GET',
