@@ -28,6 +28,19 @@ class TestUsers(base.RequestsMockTestCase):
             service_type='identity', interface='admin', resource=resource,
             append=append, base_url_append=base_url_append)
 
+    def _get_user_list(self, user_data):
+        uri = self._get_keystone_mock_url(resource='users')
+        return {
+            'users': [
+                user_data.json_response['user'],
+            ],
+            'links': {
+                'self': uri,
+                'previous': None,
+                'next': None,
+            }
+        }
+
     def test_create_user_v2(self):
         self.use_keystone_v2()
 
@@ -54,7 +67,6 @@ class TestUsers(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_create_user_v3(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data(
             domain_id=uuid.uuid4().hex,
             description=self.getUniqueString('description'))
@@ -99,7 +111,7 @@ class TestUsers(base.RequestsMockTestCase):
             #     but is always chained together [keystoneclient oddity]
             # GET user info after user update
             dict(method='GET', uri=mock_users_uri, status_code=200,
-                 json={'users': [user_data.json_response['user']]}),
+                 json=self._get_user_list(user_data)),
             dict(method='GET', uri=mock_user_resource_uri, status_code=200,
                  json=user_data.json_response),
             dict(method='PUT',
@@ -136,7 +148,6 @@ class TestUsers(base.RequestsMockTestCase):
                 password=user_data.password)
 
     def test_delete_user(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data(domain_id=uuid.uuid4().hex)
         user_resource_uri = self._get_keystone_mock_url(
             resource='users', append=[user_data.user_id])
@@ -145,7 +156,7 @@ class TestUsers(base.RequestsMockTestCase):
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='users'),
                  status_code=200,
-                 json={'users': [user_data.json_response['user']]}),
+                 json=self._get_user_list(user_data)),
             dict(method='GET', uri=user_resource_uri, status_code=200,
                  json=user_data.json_response),
             dict(method='DELETE', uri=user_resource_uri, status_code=204)])
@@ -154,7 +165,6 @@ class TestUsers(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_delete_user_not_found(self):
-        self._add_discovery_uri_call()
         self.register_uris([
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='users'),
@@ -162,7 +172,6 @@ class TestUsers(base.RequestsMockTestCase):
         self.assertFalse(self.op_cloud.delete_user(self.getUniqueString()))
 
     def test_add_user_to_group(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data()
         group_data = self._get_group_data()
 
@@ -170,7 +179,7 @@ class TestUsers(base.RequestsMockTestCase):
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='users'),
                  status_code=200,
-                 json={'users': [user_data.json_response['user']]}),
+                 json=self._get_user_list(user_data)),
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='groups'),
                  status_code=200,
@@ -184,7 +193,6 @@ class TestUsers(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_is_user_in_group(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data()
         group_data = self._get_group_data()
 
@@ -192,7 +200,7 @@ class TestUsers(base.RequestsMockTestCase):
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='users'),
                  status_code=200,
-                 json={'users': [user_data.json_response['user']]}),
+                 json=self._get_user_list(user_data)),
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='groups'),
                  status_code=200,
@@ -208,14 +216,13 @@ class TestUsers(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_remove_user_from_group(self):
-        self._add_discovery_uri_call()
         user_data = self._get_user_data()
         group_data = self._get_group_data()
 
         self.register_uris([
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='users'),
-                 json={'users': [user_data.json_response['user']]}),
+                 json=self._get_user_list(user_data)),
             dict(method='GET',
                  uri=self._get_keystone_mock_url(resource='groups'),
                  status_code=200,
